Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 15 variants Config(String), Header(InvalidHeaderValue), Transport { method: Method, endpoint: String, source: Error, }, Api { method: Method, endpoint: String, status: StatusCode, body: String, }, Storage { context: String, status: Option<StatusCode>, body: Option<String>, source: Option<Error>, }, StreamNotFound { name: String, }, StreamIdNotFound { id: i32, }, NoBackup { id: i32, }, ImportTimeout { timeout_secs: u64, last_status: String, }, ImportFailed { id: i32, message: String, }, Protocol(String), Io(Error), Url(ParseError), Json(Error), IntegerConversion(TryFromIntError),
}
Error type returned by the MarpleDB SDK.

Transport means no usable HTTP response was received, Api means the MarpleDB API returned a non-success status, and Storage covers direct pre-signed storage uploads/downloads.

match error {
    marple_db::Error::Api { status, body, .. } => {
        eprintln!("API returned {status}: {body}");
    }
    error if error.status().is_some() => {
        eprintln!("HTTP-like error: {:?}", error.status());
    }
    error => eprintln!("{error}"),
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Config(String)

The SDK was configured with invalid input.



Header(InvalidHeaderValue)

Building an HTTP header failed.



Transport

A request failed before receiving an API response.

Fields

method: Method

HTTP method used for the request.

endpoint: String

API endpoint or URL being requested.

source: Error

Underlying reqwest error.



Api

The MarpleDB API returned a non-success HTTP status.

Fields

method: Method

HTTP method used for the request.

endpoint: String

API endpoint being requested.

status: StatusCode

Response status code.

body: String

Response body text.



Storage

Direct storage upload or download failed.

Fields

context: String

Human-readable storage operation context.

status: Option<StatusCode>

HTTP status code when the storage service responded with one.

body: Option<String>

Response body text when available.

source: Option<Error>

Underlying reqwest error when the request failed before a response.



StreamNotFound

A stream with the requested name was not found.

Fields

name: String

Requested stream name.



StreamIdNotFound

A stream with the requested id was not found.

Fields

id: i32

Requested stream id.



NoBackup

The dataset has no original-file backup available for download.

Fields

id: i32

Dataset id.



ImportTimeout

Import polling reached its timeout before a terminal status.

Fields

timeout_secs: u64

Timeout in seconds.

last_status: String

Last observed import status.



ImportFailed

Import polling reached a failed terminal status.

Fields

id: i32

Dataset id.

message: String

Failure message from the API, if present.



Protocol(String)

The API returned a response that does not match the SDK protocol.



Io(Error)

Local filesystem I/O failed.



Url(ParseError)

URL parsing failed.



Json(Error)

JSON serialization or deserialization failed.



IntegerConversion(TryFromIntError)

Integer conversion failed.

Implementations

Source

impl Error

pub fn status(&self) -> Option<StatusCode>

Returns the HTTP status for API or storage responses that provided one.